@@ -1,6 +1,6 @@
 /*
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2014 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2015 by Paolo Lucente
 */
 
 /*
@@ -25,6 +25,7 @@
 
 /* defines */
 #define AMQP_DEFAULT_RETRY	60
+#define AMQP_LONGLONG_RETRY	INT_MAX
 #define PM_AMQP_MIN_FRAME_SIZE	4096
 
 /* structures */
@@ -44,15 +45,19 @@ struct p_amqp_host {
   char *host;
   char *vhost;
   int persistent_msg;
+  u_int8_t content_type;
   u_int32_t frame_max;
-  u_int32_t heartbeat_interval;
+  int heartbeat_interval;
 
   amqp_connection_state_t conn;
   amqp_socket_t *socket;
   amqp_rpc_reply_t ret;
+  amqp_bytes_t queue;
   struct amqp_basic_properties_t_ msg_props;
   int status;
+
   time_t last_fail;
+  int retry_interval;
 };
 
 /* prototypes */
@@ -75,18 +80,26 @@ EXT void p_amqp_set_host(struct p_amqp_host *, char *);
 EXT void p_amqp_set_vhost(struct p_amqp_host *, char *);
 EXT void p_amqp_set_persistent_msg(struct p_amqp_host *, int);
 EXT void p_amqp_set_frame_max(struct p_amqp_host *, u_int32_t);
-EXT void p_amqp_set_heartbeat_interval(struct p_amqp_host *, u_int32_t);
+EXT void p_amqp_set_heartbeat_interval(struct p_amqp_host *, int);
 EXT void p_amqp_set_last_fail(struct p_amqp_host *, time_t);
+EXT void p_amqp_set_retry_interval(struct p_amqp_host *, int);
+EXT void p_amqp_set_content_type_json(struct p_amqp_host *);
+EXT void p_amqp_set_content_type_binary(struct p_amqp_host *);
 
 EXT time_t p_amqp_get_last_fail(struct p_amqp_host *);
+EXT int p_amqp_get_retry_interval(struct p_amqp_host *);
 EXT char *p_amqp_get_routing_key(struct p_amqp_host *);
 EXT int p_amqp_get_routing_key_rr(struct p_amqp_host *);
+EXT int p_amqp_get_sockfd(struct p_amqp_host *);
 
 EXT void p_amqp_unset_routing_key(struct p_amqp_host *);
 EXT void p_amqp_unset_last_fail(struct p_amqp_host *);
 
-EXT int p_amqp_connect(struct p_amqp_host *);
-EXT int p_amqp_publish(struct p_amqp_host *, char *);
+EXT int p_amqp_connect_to_publish(struct p_amqp_host *);
+EXT int p_amqp_connect_to_consume(struct p_amqp_host *);
+EXT int p_amqp_publish_string(struct p_amqp_host *, char *);
+EXT int p_amqp_publish_binary(struct p_amqp_host *, void *, u_int32_t);
+EXT int p_amqp_consume_binary(struct p_amqp_host *, void *, u_int32_t);
 EXT void p_amqp_close(struct p_amqp_host *, int);
 EXT int p_amqp_is_alive(struct p_amqp_host *);
 
