@@ -70,7 +70,7 @@ void skinny_bgp_daemon()
 #endif
   afi_t afi;
   safi_t safi;
-  int clen = sizeof(client), yes=1;
+  int clen = sizeof(client), yes=1, no=0;
   u_int16_t remote_as = 0;
   u_int32_t remote_as4 = 0;
   time_t now, dump_refresh_deadline;
@@ -98,7 +98,7 @@ void skinny_bgp_daemon()
   bgp_attr_init();
 
   /* socket creation for BGP server: IPv4 only */
-#if (defined ENABLE_IPV6 && defined V4_MAPPED)
+#if (defined ENABLE_IPV6)
   if (!config.nfacctd_bgp_ip) {
     struct sockaddr_in6 *sa6 = (struct sockaddr_in6 *)&server;
 
@@ -153,12 +153,12 @@ void skinny_bgp_daemon()
     if (config.nfacctd_bgp_msglog_amqp_routing_key) {
 #ifdef WITH_RABBITMQ
       bgp_daemon_msglog_init_amqp_host();
-      p_amqp_connect(&bgp_daemon_msglog_amqp_host);
+      p_amqp_connect_to_publish(&bgp_daemon_msglog_amqp_host);
 
       if (!config.nfacctd_bgp_msglog_amqp_retry)
 	config.nfacctd_bgp_msglog_amqp_retry = AMQP_DEFAULT_RETRY;
 #else
-      Log(LOG_WARNING, "WARN ( %s/core/BGP ): p_amqp_connect() not possible due to missing --enable-rabbitmq\n", config.name);
+      Log(LOG_WARNING, "WARN ( %s/core/BGP ): p_amqp_connect_to_publish() not possible due to missing --enable-rabbitmq\n", config.name);
 #endif
     }
   }
@@ -180,7 +180,7 @@ void skinny_bgp_daemon()
 
   config.bgp_sock = socket(((struct sockaddr *)&server)->sa_family, SOCK_STREAM, 0);
   if (config.bgp_sock < 0) {
-#if (defined ENABLE_IPV6 && defined V4_MAPPED)
+#if (defined ENABLE_IPV6)
     /* retry with IPv4 */
     if (!config.nfacctd_bgp_ip) {
       struct sockaddr_in *sa4 = (struct sockaddr_in *)&server;
@@ -209,9 +209,14 @@ void skinny_bgp_daemon()
   rc = setsockopt(config.bgp_sock, SOL_SOCKET, SO_REUSEADDR, (char *)&yes, sizeof(yes));
   if (rc < 0) Log(LOG_ERR, "WARN ( %s/core/BGP ): setsockopt() failed for SO_REUSEADDR (errno: %d).\n", config.name, errno);
 
+#if (defined ENABLE_IPV6) && (defined IPV6_BINDV6ONLY)
+  rc = setsockopt(config.bgp_sock, IPPROTO_IPV6, IPV6_BINDV6ONLY, (char *) &no, (socklen_t) sizeof(no));
+  if (rc < 0) Log(LOG_ERR, "WARN ( %s/core ): setsockopt() failed for IPV6_BINDV6ONLY (errno: %d).\n", config.name, errno);
+#endif
+
   if (config.nfacctd_bgp_pipe_size) {
     int l = sizeof(config.nfacctd_bgp_pipe_size);
-    u_int64_t saved = 0, obtained = 0;
+    int saved = 0, obtained = 0;
 
     getsockopt(config.bgp_sock, SOL_SOCKET, SO_RCVBUF, &saved, &l);
     Setsocksize(config.bgp_sock, SOL_SOCKET, SO_RCVBUF, &config.nfacctd_bgp_pipe_size, sizeof(config.nfacctd_bgp_pipe_size));
@@ -219,7 +224,7 @@ void skinny_bgp_daemon()
 
     Setsocksize(config.bgp_sock, SOL_SOCKET, SO_RCVBUF, &saved, l);
     getsockopt(config.bgp_sock, SOL_SOCKET, SO_RCVBUF, &obtained, &l);
-    Log(LOG_INFO, "INFO ( %s/core/BGP ): bgp_daemon_pipe_size: obtained=%u target=%u.\n", config.name, obtained, config.nfacctd_bgp_pipe_size);
+    Log(LOG_INFO, "INFO ( %s/core/BGP ): bgp_daemon_pipe_size: obtained=%d target=%d.\n", config.name, obtained, config.nfacctd_bgp_pipe_size);
   }
 
   rc = bind(config.bgp_sock, (struct sockaddr *) &server, slen);
@@ -361,7 +366,7 @@ void skinny_bgp_daemon()
     if (config.nfacctd_bgp_msglog_file || config.nfacctd_bgp_msglog_amqp_routing_key || 
 	config.bgp_table_dump_file || config.bgp_table_dump_amqp_routing_key) {
       gettimeofday(&log_tstamp, NULL);
-      compose_timestamp(log_tstamp_str, SRVBUFLEN, &log_tstamp, TRUE);
+      compose_timestamp(log_tstamp_str, SRVBUFLEN, &log_tstamp, TRUE, config.sql_history_since_epoch);
 
       if (config.bgp_table_dump_file || config.bgp_table_dump_amqp_routing_key) {
 	while (log_tstamp.tv_sec > dump_refresh_deadline) {
@@ -374,9 +379,9 @@ void skinny_bgp_daemon()
       if (config.nfacctd_bgp_msglog_amqp_routing_key) { 
         time_t last_fail = p_amqp_get_last_fail(&bgp_daemon_msglog_amqp_host);
 
-	if (last_fail && (last_fail + config.nfacctd_bgp_msglog_amqp_retry < log_tstamp.tv_sec)) {
+	if (last_fail && ((last_fail + p_amqp_get_retry_interval(&bgp_daemon_msglog_amqp_host)) <= log_tstamp.tv_sec)) {
           bgp_daemon_msglog_init_amqp_host();
-          p_amqp_connect(&bgp_daemon_msglog_amqp_host);
+          p_amqp_connect_to_publish(&bgp_daemon_msglog_amqp_host);
 	}
       }
 #endif
