@@ -1,6 +1,6 @@
 /*
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2012 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2014 by Paolo Lucente
 */
 
 /* 
@@ -38,8 +38,16 @@ hash_create_size (unsigned int size, unsigned int (*hash_key) (void *),
   struct hash *hash;
 
   hash = malloc(sizeof (struct hash));
+  if (!hash) {
+    Log(LOG_ERR, "ERROR ( %s/core/BGP ): malloc() failed (hash_create_size). Exiting ..\n", config.name);
+    exit_all(1);
+  }
   memset (hash, 0, sizeof (struct hash));
   hash->index = malloc(sizeof (struct hash_backet *) * size);
+  if (!hash->index) {
+    Log(LOG_ERR, "ERROR ( %s/core/BGP ): malloc() failed (hash_create_size). Exiting ..\n", config.name);
+    exit_all(1);
+  }
   memset (hash->index, 0, sizeof (struct hash_backet *) * size);
   hash->size = size;
   hash->hash_key = hash_key;
@@ -54,7 +62,7 @@ struct hash *
 hash_create (unsigned int (*hash_key) (void *), 
              int (*hash_cmp) (const void *, const void *))
 {
-  return hash_create_size (HASHTABSIZE, hash_key, hash_cmp);
+  return hash_create_size (config.bgp_table_attr_hash_buckets, hash_key, hash_cmp);
 }
 
 /* Utility function for hash_get().  When this function is specified
@@ -91,6 +99,10 @@ hash_get (struct hash *hash, void *data, void * (*alloc_func) (void *))
 	return NULL;
 
       backet = malloc(sizeof (struct hash_backet));
+      if (!backet) {
+        Log(LOG_ERR, "ERROR ( %s/core/BGP ): malloc() failed (hash_get). Exiting ..\n", config.name);
+        exit_all(1);
+      }
       memset(backet, 0, sizeof (struct hash_backet));
       backet->data = newdata;
       backet->key = key;
