@@ -23,6 +23,10 @@
 #define _BGP_LOGDUMP_H_
 
 /* defines */
+#define BGP_LOGDUMP_ET_NONE	0
+#define BGP_LOGDUMP_ET_LOG	1
+#define BGP_LOGDUMP_ET_DUMP	2
+
 struct bgp_peer_log {
   FILE *fd;
   int refcnt;
@@ -30,6 +34,11 @@ struct bgp_peer_log {
   void *amqp_host;
 };
 
+struct bgp_dump_stats {
+  u_int64_t entries;
+  u_int32_t tables;
+};
+
 /* prototypes */
 #if (!defined __BGP_LOGDUMP_C)
 #define EXT extern
@@ -43,7 +52,7 @@ EXT void bgp_peer_log_seq_increment(u_int64_t *);
 EXT void bgp_peer_log_dynname(char *, int, char *, struct bgp_peer *);
 EXT int bgp_peer_log_msg(struct bgp_node *, struct bgp_info *, safi_t, char *, int);
 EXT int bgp_peer_dump_init(struct bgp_peer *, int, int);
-EXT int bgp_peer_dump_close(struct bgp_peer *, int, int);
+EXT int bgp_peer_dump_close(struct bgp_peer *, struct bgp_dump_stats *, int, int);
 EXT void bgp_handle_dump_event();
 EXT void bgp_daemon_msglog_init_amqp_host();
 EXT void bgp_table_dump_init_amqp_host();
