@@ -1,6 +1,6 @@
 /*
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2012 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2014 by Paolo Lucente
 */
 
 /* 
@@ -245,6 +245,10 @@ str2prefix_ipv4 (const char *str, struct prefix_ipv4 *p)
   else
     {
       cp = malloc ((pnt - str) + 1);
+      if (!cp) {
+	Log(LOG_ERR, "ERROR ( %s/core/BGP ): malloc() failed (str2prefix_ipv4). Exiting ..\n", config.name);
+	exit_all(1);
+      }
       strncpy (cp, str, pnt - str);
       *(cp + (pnt - str)) = '\0';
       ret = inet_aton (cp, &p->prefix);
@@ -390,6 +394,10 @@ str2prefix_ipv6 (const char *str, struct prefix_ipv6 *p)
       int plen;
 
       cp = malloc((pnt - str) + 1);
+      if (!cp) {
+	Log(LOG_ERR, "ERROR ( %s/core/BGP ): malloc() failed (str2prefix_ipv6). Exiting ..\n", config.name);
+	exit_all(1);
+      }
       strncpy (cp, str, pnt - str);
       *(cp + (pnt - str)) = '\0';
       ret = inet_pton (AF_INET6, cp, &p->prefix);
@@ -630,6 +638,10 @@ prefix_new ()
   struct prefix *p;
 
   p = malloc (sizeof *p);
+  if (!p) {
+    Log(LOG_ERR, "ERROR ( %s/core/BGP ): malloc() failed (prefix_new). Exiting ..\n", config.name);
+    exit_all(1);
+  }
   memset(p, 0, sizeof *p); 
 
   return p;
