@@ -33,12 +33,14 @@ EXT int cfg_key_logfile(char *, char *, char *);
 EXT int cfg_key_pidfile(char *, char *, char *);
 EXT int cfg_key_daemonize(char *, char *, char *);
 EXT int cfg_key_proc_name(char *, char *, char *);
+EXT int cfg_key_proc_priority(char *, char *, char *);
 EXT int cfg_key_aggregate(char *, char *, char *);
 EXT int cfg_key_aggregate_primitives(char *, char *, char *);
 EXT int cfg_key_snaplen(char *, char *, char *);
 EXT int cfg_key_aggregate_filter(char *, char *, char *);
 EXT int cfg_key_pcap_filter(char *, char *, char *);
 EXT int cfg_key_use_ip_next_hop(char *, char *, char *);
+EXT int cfg_key_thread_stack(char *, char *, char *);
 EXT int cfg_key_interface(char *, char *, char *);
 EXT int cfg_key_interface_wait(char *, char *, char *);
 EXT int cfg_key_files_umask(char *, char *, char *);
@@ -93,10 +95,19 @@ EXT int cfg_key_amqp_vhost(char *, char *, char *);
 EXT int cfg_key_amqp_routing_key_rr(char *, char *, char *);
 EXT int cfg_key_plugin_pipe_size(char *, char *, char *);
 EXT int cfg_key_plugin_pipe_backlog(char *, char *, char *);
+EXT int cfg_key_plugin_pipe_amqp(char *, char *, char *);
+EXT int cfg_key_plugin_pipe_amqp_user(char *, char *, char *);
+EXT int cfg_key_plugin_pipe_amqp_passwd(char *, char *, char *);
+EXT int cfg_key_plugin_pipe_amqp_exchange(char *, char *, char *);
+EXT int cfg_key_plugin_pipe_amqp_host(char *, char *, char *);
+EXT int cfg_key_plugin_pipe_amqp_vhost(char *, char *, char *);
+EXT int cfg_key_plugin_pipe_amqp_routing_key(char *, char *, char *);
+EXT int cfg_key_plugin_pipe_amqp_retry(char *, char *, char *);
 EXT int cfg_key_plugin_buffer_size(char *, char *, char *);
 EXT int cfg_key_networks_mask(char *, char *, char *);
 EXT int cfg_key_networks_file(char *, char *, char *);
 EXT int cfg_key_networks_file_filter(char *, char *, char *);
+EXT int cfg_key_networks_file_no_lpm(char *, char *, char *);
 EXT int cfg_key_networks_cache_entries(char *, char *, char *);
 EXT int cfg_key_ports_file(char *, char *, char *);
 EXT int cfg_key_print_cache_entries(char *, char *, char *);
@@ -128,6 +139,8 @@ EXT int cfg_key_pmacctd_flow_lifetime(char *, char *, char *);
 EXT int cfg_key_pmacctd_flow_tcp_lifetime(char *, char *, char *);
 EXT int cfg_key_pmacctd_ext_sampling_rate(char *, char *, char *);
 EXT int cfg_key_sfacctd_renormalize(char *, char *, char *);
+EXT int cfg_key_sfacctd_counter_output(char *, char *, char *);
+EXT int cfg_key_sfacctd_counter_file(char *, char *, char *);
 EXT int cfg_key_pcap_savefile(char *, char *, char *);
 EXT int cfg_key_maps_refresh(char *, char *, char *);
 EXT int cfg_key_maps_index(char *, char *, char *);
@@ -278,6 +291,7 @@ EXT int cfg_key_igp_daemon_map(char *, char *, char *);
 EXT int cfg_key_igp_daemon_map_msglog(char *, char *, char *);
 EXT int cfg_key_geoip_ipv4_file(char *, char *, char *);
 EXT int cfg_key_geoip_ipv6_file(char *, char *, char *);
+EXT int cfg_key_geoipv2_file(char *, char *, char *);
 EXT int cfg_key_uacctd_group(char *, char *, char *);
 EXT int cfg_key_uacctd_nl_size(char *, char *, char *);
 EXT int cfg_key_tunnel_0(char *, char *, char *);
