@@ -1,6 +1,6 @@
 /*
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2010 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2013 by Paolo Lucente
 */
 
 /*
@@ -644,6 +644,13 @@ pm_class_t pmct_find_first_free()
     idx++;
   }
 
+  if (num && idx == num) {
+    if (!log_notification_isset(log_notifications.max_classifiers)) {
+      Log(LOG_WARNING, "WARN ( %s/%s ): Finished elements in class table (%u). Raise via classifier_table_num.\n", config.name, config.type, num);
+      log_notification_set(&log_notifications.max_classifiers);
+    }
+  }
+
   return 0;
 }
 
