@@ -1,6 +1,6 @@
 /*
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2010 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2014 by Paolo Lucente
 */
 
 /*
@@ -33,11 +33,16 @@ struct acc {
   pm_counter_t bytes_counter;
   pm_counter_t packet_counter;
   pm_counter_t flow_counter;
+  u_int8_t flow_type; 
   u_int32_t tcp_flags; 
   unsigned int signature;
   u_int8_t reset_flag;
   struct timeval rstamp;	/* classifiers: reset timestamp */
   struct cache_bgp_primitives *cbgp;
+  struct pkt_nat_primitives *pnat;
+  struct pkt_mpls_primitives *pmpls;
+  char *pcust;
+  struct pkt_vlen_hdr_primitives *pvlen;
   struct acc *next;
 };
 
@@ -56,18 +61,26 @@ struct memory_pool_desc {
 };
 
 struct query_header {
-  int type;			/* type of query */
-  u_int64_t what_to_count;	/* aggregation */
-  unsigned int num;		/* number of queries */
-  unsigned int ip_sz;		/* IP addresses size (in bytes) */
-  unsigned int cnt_sz;		/* counters size (in bytes) */
-  char passwd[12];		/* OBSOLETED: password */
+  int type;				/* type of query */
+  pm_cfgreg_t what_to_count;		/* aggregation */
+  pm_cfgreg_t what_to_count_2;		/* aggregation */
+  unsigned int num;			/* number of queries */
+  unsigned int ip_sz;			/* IP addresses size (in bytes) */
+  unsigned int cnt_sz;			/* counters size (in bytes) */
+  struct extra_primitives extras;	/* offsets for non-standard aggregation primitives structures */
+  int datasize;				/* total length of aggregation primitives structures */
+  char passwd[12];			/* OBSOLETED: password */
 };
 
 struct query_entry {
-  u_int64_t what_to_count;	/* aggregation */
-  struct pkt_primitives data;	/* actual data */
-  struct pkt_bgp_primitives pbgp; /* extended BGP data */
+  pm_cfgreg_t what_to_count;		/* aggregation */
+  pm_cfgreg_t what_to_count_2;		/* aggregation */
+  struct pkt_primitives data;		/* actual data */
+  struct pkt_bgp_primitives pbgp;	/* extended BGP data */
+  struct pkt_nat_primitives pnat;	/* extended NAT + timestamp data */
+  struct pkt_mpls_primitives pmpls;	/* extended MPLS data */
+  char *pcust;				/* custom-defined data */
+  struct pkt_vlen_hdr_primitives *pvlen;/* variable-length data */
 };
 
 struct reply_buffer {
@@ -82,15 +95,37 @@ struct stripped_class {
   char protocol[MAX_PROTOCOL_LEN];
 };
 
+struct stripped_pkt_len_distrib {
+  char str[MAX_PKT_LEN_DISTRIB_LEN];
+};
+
+struct imt_custom_primitive_entry {
+  /* compiled from map */
+  u_char name[MAX_CUSTOM_PRIMITIVE_NAMELEN];
+  u_int16_t field_type;
+  u_int16_t len;
+  u_int8_t semantics;
+
+  /* compiled internally */
+  u_int16_t off;
+  pm_cfgreg_t type;
+};
+
+struct imt_custom_primitives {
+  struct imt_custom_primitive_entry primitive[MAX_CUSTOM_PRIMITIVES];
+  int len;
+  int num;
+};
+
 /* prototypes */
 #if (!defined __ACCT_C)
 #define EXT extern
 #else
 #define EXT
 #endif
-EXT void insert_accounting_structure(struct pkt_data *, struct pkt_bgp_primitives *);
-EXT struct acc *search_accounting_structure(struct pkt_primitives *, struct pkt_bgp_primitives *);
-EXT int compare_accounting_structure(struct acc *, struct pkt_primitives *, struct pkt_bgp_primitives *);
+EXT void insert_accounting_structure(struct primitives_ptrs *);
+EXT struct acc *search_accounting_structure(struct primitives_ptrs *);
+EXT int compare_accounting_structure(struct acc *, struct primitives_ptrs *);
 #undef EXT
 
 #if (!defined __MEMORY_C)
@@ -111,10 +146,13 @@ EXT struct memory_pool_desc *request_memory_pool(int);
 EXT void set_reset_flag(struct acc *);
 EXT void reset_counters(struct acc *);
 EXT int build_query_server(char *);
-EXT void process_query_data(int, unsigned char *, int, int);
-EXT void mask_elem(struct pkt_primitives *, struct pkt_bgp_primitives *, struct acc *, u_int64_t);
+EXT void process_query_data(int, unsigned char *, int, struct extra_primitives *, int, int);
+EXT void mask_elem(struct pkt_primitives *, struct pkt_bgp_primitives *, struct pkt_nat_primitives *,
+			struct pkt_mpls_primitives *, struct acc *, u_int64_t, u_int64_t,
+			struct extra_primitives *);
 EXT void enQueue_elem(int, struct reply_buffer *, void *, int, int);
 EXT void Accumulate_Counters(struct pkt_data *, struct acc *);
+EXT int test_zero_elem(struct acc *);
 #undef EXT
 
 #if (!defined __IMT_PLUGIN_C)
@@ -122,14 +160,14 @@ EXT void Accumulate_Counters(struct pkt_data *, struct acc *);
 #else
 #define EXT
 #endif
-EXT void sum_host_insert(struct pkt_data *, struct pkt_bgp_primitives *);
-EXT void sum_port_insert(struct pkt_data *, struct pkt_bgp_primitives *);
-EXT void sum_as_insert(struct pkt_data *, struct pkt_bgp_primitives *);
+EXT void sum_host_insert(struct primitives_ptrs *);
+EXT void sum_port_insert(struct primitives_ptrs *);
+EXT void sum_as_insert(struct primitives_ptrs *);
 #if defined HAVE_L2
-EXT void sum_mac_insert(struct pkt_data *, struct pkt_bgp_primitives *);
+EXT void sum_mac_insert(struct primitives_ptrs *);
 #endif
 EXT void exit_now(int);
-EXT void free_bgp_allocs();
+EXT void free_extra_allocs();
 #undef EXT
 
 /* global vars */
@@ -138,7 +176,7 @@ EXT void free_bgp_allocs();
 #else
 #define EXT
 #endif
-EXT void (*insert_func)(struct pkt_data *, struct pkt_bgp_primitives *); /* pointer to INSERT function */
+EXT void (*insert_func)(struct primitives_ptrs *); /* pointer to INSERT function */
 EXT unsigned char *mpd;  /* memory pool descriptors table */
 EXT unsigned char *a;  /* accounting in-memory table */
 EXT struct memory_pool_desc *current_pool; /* pointer to currently used memory pool */
