@@ -22,13 +22,13 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $Id: netflow1.c,v 1.2 2009/11/29 13:45:52 paolo Exp $ */
+/* $Id: netflow1.c,v 1.3 2012/12/21 19:10:40 paolo Exp $ */
 
 #include "common.h"
 #include "treetype.h"
 #include "nfprobe_plugin.h"
 
-RCSID("$Id: netflow1.c,v 1.2 2009/11/29 13:45:52 paolo Exp $");
+RCSID("$Id: netflow1.c,v 1.3 2012/12/21 19:10:40 paolo Exp $");
 
 /*
  * This is the Cisco Netflow(tm) version 1 packet format
@@ -87,8 +87,10 @@ send_netflow_v1(struct FLOW **flows, int num_flows, int nfsock,
 			errsz = sizeof(err);
 			getsockopt(nfsock, SOL_SOCKET, SO_ERROR,
 			    &err, &errsz); /* Clear ICMP errors */
-			if (send(nfsock, packet, (size_t)offset, 0) == -1)
-				return (-1);
+			if (send(nfsock, packet, (size_t)offset, 0) == -1) {
+			  Log(LOG_WARNING, "WARN ( %s/%s ): send() failed: %s\n", config.name, config.type, strerror(errno));
+			  return (-1);
+			}
 			*flows_exported += j;
 			j = 0;
 			num_packets++;
@@ -163,8 +165,10 @@ send_netflow_v1(struct FLOW **flows, int num_flows, int nfsock,
 		errsz = sizeof(err);
 		getsockopt(nfsock, SOL_SOCKET, SO_ERROR,
 		    &err, &errsz); /* Clear ICMP errors */
-		if (send(nfsock, packet, (size_t)offset, 0) == -1)
-			return (-1);
+		if (send(nfsock, packet, (size_t)offset, 0) == -1) {
+		  Log(LOG_WARNING, "WARN ( %s/%s ): send() failed: %s\n", config.name, config.type, strerror(errno));
+		  return (-1);
+		}
 		num_packets++;
 	}
 
