@@ -1,6 +1,6 @@
 /*
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2014 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2015 by Paolo Lucente
 */
 
 /*
@@ -44,15 +44,10 @@ void pcap_cb(u_char *user, const struct pcap_pkthdr *pkthdr, const u_char *buf)
   /* We process the packet with the appropriate
      data link layer function */
   if (buf) {
+    memset(&pptrs, 0, sizeof(pptrs));
+
     pptrs.pkthdr = (struct pcap_pkthdr *) pkthdr;
     pptrs.packet_ptr = (u_char *) buf;
-    pptrs.mac_ptr = 0; pptrs.vlan_ptr = 0; pptrs.mpls_ptr = 0;
-    pptrs.iph_ptr = 0; pptrs.tlh_ptr = 0; pptrs.payload_ptr = 0;
-    pptrs.pf = 0; pptrs.shadow = 0; pptrs.tag = 0; pptrs.tag2 = 0;
-    pretag_free_label(&pptrs.label); pptrs.class = 0; pptrs.bpas = 0;
-    pptrs.bta = 0; pptrs.blp = 0; pptrs.bmed = 0; pptrs.bitr = 0;
-    pptrs.bta2 = 0; pptrs.bta_af = 0;
-    pptrs.tun_layer = 0; pptrs.tun_stack = 0;
     pptrs.f_agent = cb_data->f_agent;
     pptrs.bpas_table = cb_data->bpas_table;
     pptrs.blp_table = cb_data->blp_table;
@@ -60,7 +55,6 @@ void pcap_cb(u_char *user, const struct pcap_pkthdr *pkthdr, const u_char *buf)
     pptrs.bta_table = cb_data->bta_table;
     pptrs.ifindex_in = cb_data->ifindex_in;
     pptrs.ifindex_out = cb_data->ifindex_out;
-    pptrs.f_status = NULL;
     pptrs.flow_type = NF9_FTYPE_TRAFFIC;
 
     (*device->data->handler)(pkthdr, &pptrs);
