@@ -309,14 +309,24 @@ static const struct _dictionary_line dictionary[] = {
   {"promisc", cfg_key_promisc},
   {"pcap_filter", cfg_key_pcap_filter},
   {"core_proc_name", cfg_key_proc_name},
+  {"proc_priority", cfg_key_proc_priority},
   {"pmacctd_as", cfg_key_nfacctd_as_new},
   {"uacctd_as", cfg_key_nfacctd_as_new},
   {"pmacctd_net", cfg_key_nfacctd_net},
   {"uacctd_net", cfg_key_nfacctd_net},
   {"use_ip_next_hop", cfg_key_use_ip_next_hop},
+  {"thread_stack", cfg_key_thread_stack},
   {"plugins", NULL},
   {"plugin_pipe_size", cfg_key_plugin_pipe_size},
   {"plugin_pipe_backlog", cfg_key_plugin_pipe_backlog},
+  {"plugin_pipe_amqp", cfg_key_plugin_pipe_amqp},
+  {"plugin_pipe_amqp_user", cfg_key_plugin_pipe_amqp_user},
+  {"plugin_pipe_amqp_passwd", cfg_key_plugin_pipe_amqp_passwd},
+  {"plugin_pipe_amqp_exchange", cfg_key_plugin_pipe_amqp_exchange},
+  {"plugin_pipe_amqp_host", cfg_key_plugin_pipe_amqp_host},
+  {"plugin_pipe_amqp_vhost", cfg_key_plugin_pipe_amqp_vhost},
+  {"plugin_pipe_amqp_routing_key", cfg_key_plugin_pipe_amqp_routing_key},
+  {"plugin_pipe_amqp_retry", cfg_key_plugin_pipe_amqp_retry},
   {"plugin_buffer_size", cfg_key_plugin_buffer_size},
   {"interface", cfg_key_interface},
   {"interface_wait", cfg_key_interface_wait},
@@ -327,9 +337,11 @@ static const struct _dictionary_line dictionary[] = {
   {"networks_mask", cfg_key_networks_mask},
   {"networks_file", cfg_key_networks_file},
   {"networks_file_filter", cfg_key_networks_file_filter},
+  {"networks_file_no_lpm", cfg_key_networks_file_no_lpm},
   {"networks_cache_entries", cfg_key_networks_cache_entries},
   {"ports_file", cfg_key_ports_file},
   {"timestamps_secs", cfg_key_timestamps_secs},
+  {"timestamps_since_epoch", cfg_key_sql_history_since_epoch},
   {"imt_path", cfg_key_imt_path},
   {"imt_passwd", cfg_key_imt_passwd},
   {"imt_buckets", cfg_key_imt_buckets},
@@ -495,6 +507,8 @@ static const struct _dictionary_line dictionary[] = {
   {"sfacctd_mcast_groups", cfg_key_nfacctd_mcast_groups},
   {"sfacctd_stitching", cfg_key_nfacctd_stitching},
   {"sfacctd_ext_sampling_rate", cfg_key_pmacctd_ext_sampling_rate},
+  {"sfacctd_counter_output", cfg_key_sfacctd_counter_output},
+  {"sfacctd_counter_file", cfg_key_sfacctd_counter_file},
   {"classifiers", cfg_key_classifiers},
   {"classifier_tentatives", cfg_key_classifier_tentatives},
   {"classifier_table_num", cfg_key_classifier_table_num},
@@ -643,6 +657,9 @@ static const struct _dictionary_line dictionary[] = {
 #if defined ENABLE_IPV6
   {"geoip_ipv6_file", cfg_key_geoip_ipv6_file},
 #endif
+#endif
+#if defined WITH_GEOIPV2
+  {"geoipv2_file", cfg_key_geoipv2_file},
 #endif
   {"uacctd_group", cfg_key_uacctd_group},
   {"uacctd_nl_size", cfg_key_uacctd_nl_size},
