@@ -1,6 +1,6 @@
 /*  
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2014 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2015 by Paolo Lucente
 */
 
 /*
@@ -495,9 +495,9 @@ void mask_elem(struct pkt_primitives *d1, struct pkt_bgp_primitives *d2, struct
   if (w & COUNT_TAG2) d1->tag2 = s1->tag2; 
   if (w & COUNT_CLASS) d1->class = s1->class; 
 
-#if defined WITH_GEOIP
-  if (w2 & COUNT_SRC_HOST_COUNTRY) d1->src_ip_country = s1->src_ip_country; 
-  if (w2 & COUNT_DST_HOST_COUNTRY) d1->dst_ip_country = s1->dst_ip_country; 
+#if defined (WITH_GEOIP) || defined (WITH_GEOIPV2)
+  if (w2 & COUNT_SRC_HOST_COUNTRY) memcpy(&d1->src_ip_country, &s1->src_ip_country, sizeof(d1->src_ip_country)); 
+  if (w2 & COUNT_DST_HOST_COUNTRY) memcpy(&d1->dst_ip_country, &s1->dst_ip_country, sizeof(d1->dst_ip_country)); 
 #endif
   if (w2 & COUNT_SAMPLING_RATE) d1->sampling_rate = s1->sampling_rate; 
   if (w2 & COUNT_PKT_LEN_DISTRIB) d1->pkt_len_distrib = s1->pkt_len_distrib; 
