@@ -24,6 +24,8 @@
 
 /* includes */
 #include "pmacct.h"
+#include "pmacct-data.h"
+#include "plugin_hooks.h"
 
 /* extern */
 extern struct plugins_list_entry *plugin_list;
@@ -92,7 +94,14 @@ void handle_falling_child()
 
 void ignore_falling_child()
 {
-  while (waitpid(-1, 0, WNOHANG) > 0) sql_writers.retired++;
+  pid_t cpid;
+  int status;
+
+  while ((cpid = waitpid(-1, &status, WNOHANG)) > 0) {
+    if (!WIFEXITED(status)) Log(LOG_WARNING, "WARN ( %s/%s ): Abnormal exit status detected for child PID %u\n", config.name, config.type, cpid);
+    sql_writers.retired++;
+  }
+
   signal(SIGCHLD, ignore_falling_child);
 }
 
@@ -127,7 +136,7 @@ void my_sigint_handler(int signum)
 
   wait(NULL);
 
-  Log(LOG_INFO, "OK: Exiting ...\n");
+  Log(LOG_INFO, "INFO ( %s/%s ): OK, Exiting ...\n", config.name, config.type);
 
   if (config.acct_type == ACCT_PM && !config.uacctd_group /* XXX */) {
     if (config.dev) {
@@ -163,6 +172,8 @@ void reload()
   }
 
   if (config.nfacctd_bgp_msglog_file) reload_log_bgp_thread = TRUE;
+  if (config.nfacctd_bmp_msglog_file) reload_log_bmp_thread = TRUE;
+  if (config.sfacctd_counter_file) reload_log_sf_cnt = TRUE;
 
   signal(SIGHUP, reload);
 }
@@ -190,11 +201,13 @@ void reload_maps()
   reload_map = FALSE;
   reload_map_bgp_thread = FALSE;
   reload_map_exec_plugins = FALSE;
+  reload_geoipv2_file = FALSE;
 
   if (config.maps_refresh) {
     reload_map = TRUE; 
     reload_map_bgp_thread = TRUE;
     reload_map_exec_plugins = TRUE;
+    reload_geoipv2_file = TRUE;
   }
   
   signal(SIGUSR2, reload_maps);
